@@ -71,6 +71,7 @@ void MainWindow::initialize()
     centralWidget()->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding);
     connect(Core::map(), SIGNAL(objectClicked(GMWItem*)), this, SLOT(objectClicked(GMWItem*)));
     connect(Core::map(), SIGNAL(showList()), this, SLOT(showList()));
+    connect(Core::map(), SIGNAL(resized()), SLOT(mapResized()));
 
     // create Engine
     connect(Core::engine(), SIGNAL(downloadStarted()), SLOT(downloadStarted()));
@@ -103,7 +104,7 @@ void MainWindow::initialize()
     if (m_gps) {
         m_gps->setUpdateInterval(5000);
         connect(m_gps, SIGNAL(positionUpdated(const QGeoPositionInfo&)), this, SLOT(positionUpdated(const QGeoPositionInfo&)));
-        m_gps->startUpdates();
+//        m_gps->startUpdates();
     } else {
         qDebug() << "No GPS available";
         //m_map->positionUpdated(QGeoPositionInfo(QGeoCoordinate(-27.5796, 153.1), QDateTime::currentDateTime()));
@@ -112,8 +113,6 @@ void MainWindow::initialize()
     Core::map()->setTracking(true);
 
     grabZoomKeys(true);
-
-    centerOnStartCoordinates();
 }
 
 MainWindow::~MainWindow(){
@@ -250,7 +249,7 @@ void MainWindow::loadSettings() {
 
     if(changed) {
         qDebug() << "centering!";
-        staticMetaObject.invokeMethod(this, "centerOnStartCoordinates", Qt::QueuedConnection);
+        centerOnStartCoordinates();
     }
 
 #ifdef Q_WS_MAEMO_5
@@ -355,3 +354,26 @@ void MainWindow::itemDialogClosed() {
     m_itemDialog->deleteLater();
     m_itemDialog = 0;
 }
+
+
+/* The next two functions are used as a workaround to center the map correctly on
+ * startup. QGraphicsGeoMap has an issue in fitInViewport(). To make the map
+ * nicely usable I add this workaround. Should be removed once QGraphicsGeoMap
+ * is fixed:
+ * On startup I connect the signal resized() to the map. When the map is
+ * placed in the window, it will this emit this signal multiple times.
+ * after that we are ready to call fitInViewPort(). However, the signal will
+ * also be emitted on a screen rotate or window resize. To prevent the map
+ * beeing centered on every rotation, the signal is disconnected once tha map has
+ * been panned
+ */
+void MainWindow::mapResized()
+{
+    QTimer::singleShot(0, this, SLOT(centerOnStartCoordinates()));
+}
+
+void MainWindow::mapPanned()
+{
+    disconnect(this, SLOT(mapResized()));
+    disconnect(this, SLOT(mapPanned()));
+}
