@@ -125,6 +125,8 @@ void MobilityMap::initialize()
 
     connect(map, SIGNAL(clicked(QGeoMapObject*)), SLOT(geoObjectClicked(QGeoMapObject*)));
     connect(map, SIGNAL(panned()), SLOT(disableTracking()));
+    connect(map, SIGNAL(geometryChanged()), SIGNAL(resized()));
+    connect(map, SIGNAL(panned()), SIGNAL(panned()));
 
     // Current Position
     QPixmap positionMarker(":/currentLoc.png");
@@ -183,7 +185,8 @@ void MobilityMap::zoomTo(const QGeoBoundingBox &bounds)
     // to the given bounds. We zoom in to level 12 for now as this
     // seems to be best suited to display an entire city
     m_map->setZoomLevel(12);
-
+    qDebug() << "*** setting center to" << bounds.center();
+    m_map->setCenter(bounds.center());
 }
 
 void MobilityMap::refresh()
